@@ -2,7 +2,7 @@ package MooseX::DeclareX::Keyword::role;
 
 BEGIN {
 	$MooseX::DeclareX::Keyword::role::AUTHORITY = 'cpan:TOBYINK';
-	$MooseX::DeclareX::Keyword::role::VERSION   = '0.003';
+	$MooseX::DeclareX::Keyword::role::VERSION   = '0.004';
 }
 
 require MooseX::Declare;
@@ -15,8 +15,8 @@ with 'MooseX::DeclareX::Registry';
 sub preferred_identifier { 'role' }
 
 before add_namespace_customizations => sub {
-	my ($self, $ctx) = @_;
-	$_->setup_for($ctx->namespace, provided_by => ref $self)
+	my ($self, $ctx, $pkg, $o) = @_;
+	$_->setup_for($pkg, provided_by => ref $self)
 		foreach @{ $self->default_inner };
 };
 
